@@ -138,36 +138,57 @@ def fillBucket(t,nodeToID,triplesBucket,tmap=tripleMap):
     if t.dependency in tmap:
         tmap[t.dependency](t,nodeToID,triplesBucket)
     if t.dependency.startswith('prep'): # prep_x or prepc_x
-        prep = t.dependency[t.dependency.rindex('_')+1:]
+        prep = t.dependency[t.dependency.index('_')+1:]
         tripleProduce2(t,nodeToID,triplesBucket,prep)
     for c in t.child: # could become necessary to perform this step before
         fillBucket(c,nodeToID,triplesBucket)
 
 questionMap = {
-    'What'          : 'definition',
-    'What kind'     : 'kind',
-    'What type'     : 'type',
-    'What sort'     : 'sort',
-    'What time'     : 'time',
-    'When'          : 'time',
-    'Why'           : 'reason',
-    'Where'         : 'location',
-    'Who'           : 'identity',
-    'How'           : 'way',
-    'How much'      : 'quantity',
-    'How many'      : 'number',
-    'How old'       : 'age',
-    'How far'       : 'distance',
-    'How long'      : 'length',
-    'How tall'      : 'height',
-    'How deep'      : 'depth',
-    'How wide'      : 'width',
-    'How fast'      : 'speed',
-    'How often'     : 'frequency',
-    'How come'      : 'reason',
-    'Which'         : 'identity',
-    'Whom'          : 'identity',
-    'Whose'         : 'identity'
+    # close question word
+    'is'            : 'yesno',
+    'are'           : 'yesno',
+    'am'            : 'yesno',
+    'was'           : 'yesno',
+    'were'          : 'yesno',
+    'will'          : 'yesno',
+    'do'            : 'yesno',
+    'does'          : 'yesno',
+    'did'           : 'yesno',
+    'have'          : 'yesno',
+    'had'           : 'yesno',
+    'has'           : 'yesno',
+    'can'           : 'yesno',
+    'could'         : 'yesno',
+    'should'        : 'yesno',
+    'shall'         : 'yesno',
+    'may'           : 'yesno',
+    'might'         : 'yesno',
+    'would'         : 'yesno',
+    # open question word
+    'what'          : 'definition',
+    'what kind'     : 'description',
+    'what type'     : 'type',
+    'what sort'     : 'type',
+    'what time'     : 'time',
+    'when'          : 'time',
+    'why'           : 'reason',
+    'where'         : 'place',
+    'who'           : 'person',
+    'how'           : 'manner',
+    'how much'      : 'amount',
+    'how many'      : 'quantity',
+    'how old'       : 'age',
+    'how far'       : 'distance',
+    'how long'      : 'length',
+    'how tall'      : 'height',
+    'how deep'      : 'depth',
+    'how wide'      : 'width',
+    'how fast'      : 'speed',
+    'how often'     : 'frequency',
+    'how come'      : 'reason',
+    'which'         : 'choice',
+    'whom'          : 'person',
+    'whose'         : 'possession'
 }
 
 def buildBucket(t,qw):
